@@ -57,7 +57,7 @@ let decision_table l =
   match (aux max_int [] l : int * 'a list * 'b list) with
     | _,[], _ -> decision l
     | min,((_,max,_)::_ as l1), l2 ->
-	let arr = Array.create (max-min+1) 0 in
+	let arr = Array.make (max-min+1) 0 in
 	List.iter (fun (a,b,i) -> for j = a to b do arr.(j-min) <- i + 1 done) l1;
 	Lte (min-1, Return (-1), Lte (max, Table (min,arr), decision l2))
 
@@ -213,6 +213,11 @@ EXTEND Gram
  regexp: [
    [ r1 = regexp; "|"; r2 = regexp -> Ulex.alt r1 r2 ]
  | [ r1 = regexp; r2 = regexp -> Ulex.seq r1 r2 ]
+ | [ r1 = regexp; "#"; r2 = regexp ->
+       try  Ulex.diff r1 r2
+       with Not_found ->
+         failwith
+           ("pa_ulex (error): operands of # must be bare character sets") ]
  | [ r = regexp; "*" -> Ulex.rep r
    | r = regexp; "+" -> Ulex.plus r
    | r = regexp; "?" -> Ulex.alt Ulex.eps r
